# This perl script builds a `specs' file for gcc.

# escape blank spaces
sub escblank {
    my ($x) = @_;
    $x =~ s/ /\\ /g;
    return $x;
}

$pkgincludedir=escblank(shift);
$libdir=escblank(shift);
$cilk2cdir=escblank(shift);
$crt0dir=escblank(shift);
$pkgdatadir=escblank(shift);
$pthreadlib=shift;
$gnu_ld=shift;
$cc1=shift;
$cpp=shift;
$cpp_o=shift;
$cpp_opts=shift;
$percentc=shift;

$link = '';

if ($gnu_ld eq "yes") {
  $rpath=" -rpath ${libdir}";
} else {
  $rpath="";
}

print <<EOF;
%rename lib old_lib
*lib:
-L${crt0dir} -lcilkrt0 -L${libdir} %{!nostdlib:%{!nodefaultlibs:%{cilk-debug: %{cilk-profile:-lcilk.g.p} %{!cilk-profile:-lcilk.g}} %{!cilk-debug: %{cilk-profile:-lcilk.p} %{!cilk-profile:-lcilk}} ${pthreadlib} %G}} %(old_lib)

%rename link_libgcc old_link_libgcc
*link_libgcc:
${rpath} -L${crt0dir} -L${libdir} %(old_link_libgcc)

*cilkinclude:
-I${pkgincludedir} 

*cilkcpp:
%(cilkinclude) %{cilk-debug:-DCILK_DEBUG=1} %{cilk-profile:-DCILK_STATS=1 -DCILK_TIMING=1} %{cilk-critical-path:-DCILK_CRITICAL_PATH=1} %{cilk-critical-path:%{!cilk-profile:%e-cilk-critical-path requires -cilk-profile}} -D_REENTRANT

*cilk2c:
-W3 %{Wall:-W5} %{w:-W0} %{cilk-hint:-hint}

*cilkg:
%{g*}

*cilkp:
%{p}

.cilk:
\@cilk

\@cilk:
${cpp} -D__CILK__ %{ansi:-std=c89} %{std*} %{nostdinc*} %{C} %{v} %{A*} %{I*} %{P} %{$} %I %{C:%{!E:%eGNU C does not support -C without using -E}} %{M} %{MM} %{MD:-MD %b.d} %{MMD:-MMD %b.d} %{MG} %{!no-gcc:-D__GNUC__=%v1 -D__GNUC_MINOR__=%v2} %{ansi|std=*:%{!std=gnu*:-trigraphs -D__STRICT_ANSI__}} %{!undef:%{!ansi:%{!std=*:%p}%{std=gnu*:%p}} %P} %{trigraphs} ${percentc} %{ffast-math:-D__FAST_MATH__} %{traditional} %{ftraditional:-traditional} %{traditional-cpp:-traditional} %{fleading-underscore} %{fno-leading-underscore} %{W*} %{w} %{pedantic*} %{H} %{d*} %C %{D*} %{U*} %{i*} %Z -D__CILK2C__  %(cilkcpp) -include ${pkgincludedir}/cilk.h %i %{!M:%{!MM:%{!E:${cpp_opts} %{!pipe: ${cpp_o} %g.cilk}}}}%{E:%W{o*}}%{M:%W{o*}}%{MM:%W{o*}} |
${cilk2cdir}/cilk2c %(cilk2c) %{!pipe:%g.cilk} %{cc:%W{o*}%{!o*:-o %b.c}}%{!cc:-o %{!pipe:%g.c}} | 
%{!cc:${cpp} %{ansi:-std=c89} %(cilkinclude) %{std*} %{nostdinc*} %(cilkcpp) %{traditional} %{ftraditional:-traditional} %{traditional-cpp:-traditional} %{fleading-underscore} %{fno-leading-underscore} %{!pipe: %g.c} ${cpp_opts} %{!pipe: ${cpp_o} %g.i} |
%{!M:%{!MM:%{!E:${cc1} %{!pipe:%g.i} %1 %{!Q:-quiet} -dumpbase %b.c %{d*} %{m*} %{a*} %(cilkg) %{O*} %{W*} %{w} %{pedantic*} %{std*} %{traditional} %{v:-version} %{pg:-p} %(cilkp) %{f*} %{aux-info*} %{Qn:-fno-ident} %{--help:--help} %{pg:%{fomit-frame-pointer:%e-pg and -fomit-frame-pointer are incompatible}} %{S:%W{o*}%{!o*:-o %b.s}}%{!S:-o %{|!pipe:%g.s}} |
%{!S:as %a %Y %{c:%W{o*}%{!o*:-o %w%b%O}}%{!c:-o %d%w%u%O} %{!pipe:%g.s} %A
}}}}}
EOF

# The specs above come from gcc-2.95, but they should be reasonably
# portable to other systems.
